@@ -8,6 +8,7 @@ import time
 
 import asyncio
 from Adyan.config_mongo import settings
+from .proxy import ProxyGetter
 
 from pyppeteer import launch
 from retrying import retry
@@ -15,18 +16,18 @@ from retrying import retry
 set = settings.Settings
 
 
-async def chrome_page(url, browser=None):
+async def chrome_page(url, browser=None, proxy=None):
     if browser is None:
+        args = ['--no-sandbox']
+        if proxy:
+            print(proxy)
+            args = ['--no-sandbox', f'--proxy-server={proxy}']
         browser = await launch(options={
             'handleSIGINT': False,
             'handleSIGTERM': False,
             'handleSIGHUP': False,
             'headless': False,
-            # "userDataDir": "F:/tool/pyppeteer",
-            'args': [
-                '--no-sandbox',
-                # f'--window-size={self.width},{self.height}'
-            ]
+            'args': args
         })
     page = await browser.newPage()
     tasks = [
@@ -51,14 +52,18 @@ def _pages(browser, url):
 
 class Chrome:
 
-    async def cart(self, url):
-        page, browser = await chrome_page(url)
+    async def cart(self, url, proxy=None):
+        page, browser = await chrome_page(url, proxy)
         await Login().login(page)
         await asyncio.sleep(2)
-        slider_again = await page.Jeval('div.order-button-children-list > div:nth-child(2) > div', 'node => node.textContent')
+        slider_again = await page.Jeval(
+            'div.order-button-children-list > div:nth-child(2) > div',
+            'node => node.textContent'
+        )
         print(slider_again)
         await asyncio.sleep(2)
-        await page.click("#sku-count-widget-wrapper > div:nth-child(1) > div:nth-child(2) > span > span > span.next-input-group-addon.next-after > button")
+        await page.click(
+            "#sku-count-widget-wrapper > div:nth-child(1) > div:nth-child(2) > span > span > span.next-input-group-addon.next-after > button")
         await asyncio.sleep(2)
         await page.click('div.order-button-children-list > div:nth-child(2) > div')
         await asyncio.sleep(3)
@@ -66,11 +71,11 @@ class Chrome:
         print(cg)
         await browser.close()
 
-    def start(self, url):
+    def start(self, url, proxy=None):
         loop1 = asyncio.new_event_loop()
         asyncio.set_event_loop(loop1)
         loop = asyncio.get_event_loop()
-        loop.run_until_complete(self.cart(url))
+        loop.run_until_complete(self.cart(url, proxy))
 
 
 class Login:
@@ -103,7 +108,6 @@ class Login:
                 print('验证通过')
                 return 1, page
 
-
     async def slide(self, page):
         slider = await page.Jeval('#nc_1_n1z', 'node => node.style')
         if slider:
@@ -132,7 +136,6 @@ class Login:
                     await asyncio.sleep(5)
                     return 'cg'
 
-
     async def login(self, page, browser=None):
         await page.evaluate(
             '''() =>{ Object.defineProperties(navigator,{ webdriver:{ get: () => false } }) }''')
@@ -155,6 +158,6 @@ class Login:
 
 
 if __name__ == '__main__':
-    url ="https://detail.1688.com/offer/614252293961.html?spm=a260k.dacugeneral.home2019rec.15.6633436cLdqrVw&scm=1007.21237.114566.0&pvid=f473cbd1-fe33-4107-8601-739784cc1b83&object_id=614252293961&udsPoolId=2274586&resourceId=1797996&resultType=normal"
+    url = "https://detail.1688.com/offer/614252293961.html?spm=a260k.dacugeneral.home2019rec.15.6633436cLdqrVw&scm=1007.21237.114566.0&pvid=f473cbd1-fe33-4107-8601-739784cc1b83&object_id=614252293961&udsPoolId=2274586&resourceId=1797996&resultType=normal"
     Chrome().start(f'https://login.taobao.com/?redirect_url={url}')
     # 'https://detail.1688.com/offer/650271479831.html?spm=a260k.dacugeneral.pc_index_cht.6.6633436cLdqrVw&&object_id=650271479831&udsPoolId=2607161')
