@@ -5,7 +5,7 @@
 # @File    : settings.py
 
 
-from Utils import MongoPerson
+from ..Utils import MongoPerson
 
 
 class Settings:
