@@ -30,10 +30,13 @@ def detail():
     types = request.args.to_dict().get("type")
     host = request.args.to_dict().get("host")
     DB = request.args.to_dict().get("DB", 2)
+    dl = request.args.to_dict().get("delete")
     login_url = request.args.to_dict().get("login_url", 'https://login.taobao.com/member/login.jhtml?')
     user = set(host=host).config
     res = ReidsClient({"HOST": host, 'DB': int(DB)}).redis_conn
     ip = request.remote_addr
+    if dl:
+        res.delete(ip)
     if res.exists(ip):
         res.setrange(ip, 0, int(res.get(ip)) + 1)
     else:
